@@ -1,16 +1,9 @@
-# NOTE: The rich_text_area and rich_text_area_tag helpers are defined in a file
-# with a different name and not in the usual autoload-reachable way.
-# The following line is definitely need to make `bootstrap_form` work.
-# rubocop:disable Lint/SuppressedException
-begin
-  require "#{Gem::Specification.find_by_name('actiontext').gem_dir}/app/helpers/action_text/tag_helper"
-rescue Gem::MissingSpecError
-end
-# rubocop:enable Lint/SuppressedException
+# frozen_string_literal: true
 
 require "action_view"
 require "action_pack"
 require "bootstrap_form/action_view_extensions/form_helper"
+require "bootstrap_form/configuration"
 
 module BootstrapForm
   extend ActiveSupport::Autoload
@@ -33,12 +26,8 @@ module BootstrapForm
       BootstrapForm::Inputs.eager_load!
     end
 
-    def config
-      @config ||= BootstrapForm::Configuration.new
-    end
-
-    def configure
-      yield config
+    def deprecator
+      @deprecator ||= ActiveSupport::Deprecation.new("a future release", "BootstrapForm")
     end
   end
 
