@@ -1,10 +1,18 @@
+# frozen_string_literal: true
+
 # require 'bootstrap_form/aliasing'
 
 module BootstrapForm
-  class FormBuilder < ActionView::Helpers::FormBuilder
+  class FormBuilder < ActionView::Helpers::FormBuilder # rubocop:disable Metrics/ClassLength
     attr_reader :layout, :label_col, :control_col, :has_error, :inline_errors,
                 :label_errors, :acts_like_form_tag
 
+    class << self
+      def redefine_rich_text_area?
+        ActionView::Helpers::FormBuilder.instance_methods.any? { _1 == :rich_text_area }
+      end
+    end
+
     include BootstrapForm::Helpers::Field
     include BootstrapForm::Helpers::Bootstrap
 
@@ -32,7 +40,7 @@ module BootstrapForm
     include BootstrapForm::Inputs::PhoneField
     include BootstrapForm::Inputs::RadioButton
     include BootstrapForm::Inputs::RangeField
-    include BootstrapForm::Inputs::RichTextArea
+    include BootstrapForm::Inputs::RichTextArea if redefine_rich_text_area?
     include BootstrapForm::Inputs::SearchField
     include BootstrapForm::Inputs::Select
     include BootstrapForm::Inputs::Submit
@@ -72,10 +80,10 @@ module BootstrapForm
         .compact.uniq, " ")
     end
 
-    def fields_for_with_bootstrap(record_name, record_object=nil, fields_options={}, &block)
+    def fields_for_with_bootstrap(record_name, record_object=nil, fields_options={}, &)
       fields_options = fields_for_options(record_object, fields_options)
       record_object = nil if record_object.is_a?(Hash) && record_object.extractable_options?
-      fields_for_without_bootstrap(record_name, record_object, fields_options, &block)
+      fields_for_without_bootstrap(record_name, record_object, fields_options, &)
     end
 
     bootstrap_alias :fields_for
@@ -90,9 +98,9 @@ module BootstrapForm
       field_options = fields_options
       field_options = record_object if record_object.is_a?(Hash) && record_object.extractable_options?
       %i[layout control_col inline_errors label_errors].each do |option|
-        field_options[option] ||= options[option]
+        field_options[option] = field_options.key?(option) ? field_options[option] : options[option]
       end
-      field_options[:label_col] = field_options[:label_col].present? ? (field_options[:label_col]).to_s : options[:label_col]
+      field_options[:label_col] = field_options[:label_col].present? ? field_options[:label_col].to_s : options[:label_col]
       field_options
     end
 
