@@ -23,21 +23,21 @@ module BootstrapForm
       html_class = control_specific_class(field_name)
       html_class = "#{html_class} col-auto g-3" if @layout == :horizontal && options[:skip_inline].blank?
       tag.div(class: html_class) do
-        input_with_error(name) do
+        input_with_error(name, options[:id]) do
           send(without_field_name, name, options, html_options)
         end
       end
     end
 
-    def form_group_content(label, help_text, options, &block) # rubocop:disable Metrics/AbcSize
+    def form_group_content(label, help_text, options, &)
       label ||= ActiveSupport::SafeBuffer.new
       if group_layout_horizontal?(options[:layout])
-        label + tag.div(capture(&block) + help_text, class: form_group_control_class(options))
+        label + tag.div(capture(&) + help_text, class: form_group_control_class(options))
       else
         content = ActiveSupport::SafeBuffer.new
         # Floating labels need to be rendered after the field
         content << label unless options[:floating]
-        content << capture(&block)
+        content << capture(&)
         content << label if options[:floating]
         content << help_text if help_text
         content
