@@ -13,13 +13,15 @@ module BootstrapForm
           content = tag.div(class: check_box_wrapper_class(options), **options[:wrapper].to_h.except(:class)) do
             html = check_box_without_bootstrap(name, check_box_options(name, options), checked_value, unchecked_value)
             html << check_box_label(name, options, checked_value, &block) unless options[:skip_label]
-            html << generate_error(name) if options[:error_message]
+            html << generate_error(name, options[:id]) if options[:error_message]
             html
           end
           wrapper(content, options)
         end
 
         bootstrap_alias :check_box
+        alias_method :checkbox_with_bootstrap, :check_box_with_bootstrap if Rails::VERSION::MAJOR >= 8
+        bootstrap_alias :checkbox if Rails::VERSION::MAJOR >= 8
       end
 
       private
@@ -39,10 +41,11 @@ module BootstrapForm
                                            :inline, :label, :label_class, :label_col, :layout, :skip_label,
                                            :switch, :wrapper, :wrapper_class)
         check_box_options[:class] = check_box_classes(name, options)
+        check_box_options[:aria] = { describedby: aria_feedback_id(id: options[:id], name:) } if error?(name)
         check_box_options.merge!(required_field_options(options, name))
       end
 
-      def check_box_label(name, options, checked_value, &block)
+      def check_box_label(name, options, checked_value, &)
         label_name = if options[:multiple]
                        check_box_value(name, checked_value)
                      else
@@ -50,19 +53,20 @@ module BootstrapForm
                      end
         label_options = { class: check_box_label_class(options) }
         label_options[:for] = options[:id] if options[:id].present?
-        label(label_name, check_box_description(name, options, &block), label_options)
+        label(label_name, check_box_description(name, options, &), label_options)
       end
 
       def check_box_description(name, options, &block)
         content = block ? capture(&block) : options[:label]
-        content || object&.class&.human_attribute_name(name) || name.to_s.humanize
+        # Ugh. Next Rails after 7.1 passes `false` when there's no object.
+        content || (object && object.class.human_attribute_name(name)) || name.to_s.humanize # rubocop:disable Style/SafeNavigation
       end
 
       def check_box_value(name, value)
         # label's `for` attribute needs to match checkbox tag's id,
         # IE sanitized value, IE
         # https://github.com/rails/rails/blob/5-0-stable/actionview/lib/action_view/helpers/tags/base.rb#L123-L125
-        "#{name}_#{value.to_s.gsub(/\s/, '_').gsub(/[^-[[:word:]]]/, '').mb_chars.downcase}"
+        "#{name}_#{value.to_s.gsub(/\s/, '_').gsub(/[^-[[:word:]]]/, '').downcase}"
       end
 
       def check_box_classes(name, options)
@@ -83,7 +87,10 @@ module BootstrapForm
       def check_box_wrapper_class(options)
         classes = ["form-check"]
         classes << "form-check-inline" if layout_inline?(options[:inline])
-        classes << "mb-3" unless options[:multiple] || %i[horizontal inline].include?(layout)
+        classes << "mb-3" unless options[:multiple] ||
+                                 %i[horizontal inline].include?(layout) ||
+                                 options[:wrapper_class] == false ||
+                                 options.dig(:wrapper, :class) == false
         classes << "form-switch" if options[:switch]
         classes << options.dig(:wrapper, :class).presence
         classes << options[:wrapper_class].presence
