@@ -14,7 +14,7 @@ module BootstrapForm
           tag.div(**wrapper_attributes) do
             html = radio_button_without_bootstrap(name, value, radio_button_options(name, options))
             html << radio_button_label(name, value, options) unless options[:skip_label]
-            html << generate_error(name) if options[:error_message]
+            html << generate_error(name, options[:id]) if options[:error_message]
             html
           end
         end
@@ -28,6 +28,7 @@ module BootstrapForm
         radio_button_options = options.except(:class, :label, :label_class, :error_message, :help,
                                               :inline, :hide_label, :skip_label, :wrapper, :wrapper_class)
         radio_button_options[:class] = radio_button_classes(name, options)
+        radio_button_options[:aria] = { describedby: aria_feedback_id(id: options[:id], name:) } if error?(name)
         radio_button_options.merge!(required_field_options(options, name))
       end
 
